"""
Project information.
"""

name = 'py-opengauss'
identity = 'https://gitee.com/opengauss/openGauss-connector-python-pyog'

meaculpa = 'Python+openGauss'
abstract = 'Driver and tools library for openGauss'

version_info = (1, 3, 10)  # dev based on py-postgresql version 1.3.0
version = '.'.join(map(str, version_info))
